import Matching from './Matching.mjs';
import { TimeEstimates } from './TimeEstimates.mjs';
import Feedback from './Feedback.mjs';
import Options from './Options.mjs';
export { default as debounce } from './utils/debounce.mjs';
import Scoring from './scoring/index.mjs';

const time = () => new Date().getTime();
class ZxcvbnFactory {
  constructor(options = {}, customMatchers = {}) {
    this.options = new Options(options, customMatchers);
    this.scoring = new Scoring(this.options);
  }
  estimateAttackTimes(guesses) {
    const timeEstimates = new TimeEstimates(this.options);
    return timeEstimates.estimateAttackTimes(guesses);
  }
  getFeedback(score, sequence) {
    const feedback = new Feedback(this.options);
    return feedback.getFeedback(score, sequence);
  }
  createReturnValue(resolvedMatches, password, start) {
    const matchSequence = this.scoring.mostGuessableMatchSequence(password, resolvedMatches);
    const calcTime = time() - start;
    const attackTimes = this.estimateAttackTimes(matchSequence.guesses);
    return {
      calcTime,
      ...matchSequence,
      ...attackTimes,
      feedback: this.getFeedback(attackTimes.score, matchSequence.sequence)
    };
  }
  main(password, userInputs) {
    const userInputsOptions = this.options.getUserInputsOptions(userInputs);
    const matching = new Matching(this.options);
    return matching.match(password, userInputsOptions);
  }
  check(password, userInputs) {
    const reducedPassword = password.substring(0, this.options.maxLength);
    const start = time();
    const matches = this.main(reducedPassword, userInputs);
    if (matches instanceof Promise) {
      throw new Error('You are using a Promised matcher, please use `zxcvbnAsync` for it.');
    }
    return this.createReturnValue(matches, reducedPassword, start);
  }
  async checkAsync(password, userInputs) {
    const reducedPassword = password.substring(0, this.options.maxLength);
    const start = time();
    const matches = await this.main(reducedPassword, userInputs);
    return this.createReturnValue(matches, reducedPassword, start);
  }
}

export { ZxcvbnFactory };
//# sourceMappingURL=index.mjs.map
